==> data_copilot-0.1.1.tar.gz: data_copilot-0.1.1/.github/CONTRIBUTING.md <==
## How to contribute to Data Copilot

#### **Did you find a bug?**

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/Modulos/data_copilot/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/Modulos/data_copilot/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.

* If possible, use the relevant bug report templates to create the issue.

#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

#### **Did you fix whitespace, format code, or make a purely cosmetic patch?**

Changes that are cosmetic in nature and do not add anything substantial to the stability, functionality, or testability of Data Copilot will generally not be accepted 

#### **Do you intend to add a new feature or change an existing one?**

* Suggest your change in the [Data Copilot discord channel](https://discord.gg/864J9K5d) and start writing code.

* Do not open an issue on GitHub until you have collected positive feedback about the change. GitHub issues are primarily intended for bug reports and fixes.


#### **Do you have questions about the source code?**

* Ask any question about how to use Data Copilot in the [discord](https://discord.gg/864J9K5d).


Thanks! :heart: :heart: :heart:

Modulos Team

==> data_copilot-0.1.2.tar.gz: data_copilot-0.1.2/.github/CONTRIBUTING.md <==
## How to contribute to Data Copilot

#### **Did you find a bug?**

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/Modulos/data_copilot/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/Modulos/data_copilot/issues/new). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** or an **executable test case** demonstrating the expected behavior that is not occurring.

* If possible, use the relevant bug report templates to create the issue.

#### **Did you write a patch that fixes a bug?**

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

#### **Did you fix whitespace, format code, or make a purely cosmetic patch?**

Changes that are cosmetic in nature and do not add anything substantial to the stability, functionality, or testability of Data Copilot will generally not be accepted 

#### **Do you intend to add a new feature or change an existing one?**

* Suggest your change in the [Data Copilot discord channel](https://discord.gg/muerW29z) and start writing code.

* Do not open an issue on GitHub until you have collected positive feedback about the change. GitHub issues are primarily intended for bug reports and fixes.


#### **Do you have questions about the source code?**

* Ask any question about how to use Data Copilot in the [discord](https://discord.gg/muerW29z).


Thanks! :heart: :heart: :heart:

Modulos Team
